@@ -1,5 +1,6 @@
 import sys
 import os
+import subprocess
 from sub_formater import sft
 
 
@@ -21,5 +22,8 @@ def main():
         print(show.name)
         print(show.file_video)
         print(show.file_subtitle)
-        sft.rename(show.file_subtitle,
-                   show.file_video, workPath)
+        if show.file_video is None or show.file_subtitle is None:
+            return
+        show.file_subtitle = sft.rename(show.file_subtitle,
+                                        show.file_video, workPath)
+        subprocess.run(["ffs", show.file_video, "-i", show.file_subtitle, "-o", show.file_subtitle])
